@@ -304,6 +304,13 @@ DateCalc_easter_sunday                 (Z_int  *year,       /*  I/O  */
                                         Z_int  *month,      /*   O   */
                                         Z_int  *day);       /*   O   */
 
+boolean
+DateCalc_easter_orthodox_sunday        (Z_int  *year,       /*  I/O  */
+                                        boolean julian,     /*   I   */
+                                        Z_int  *month,      /*   O   */
+                                        Z_int  *day);       /*   O   */
+                                        
+
 Z_int
 DateCalc_Decode_Month                  (charptr buffer,
                                         Z_int   length);
@@ -403,9 +410,9 @@ const Z_int DateCalc_Days_in_Month_[2][13] =
     { 0, 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 }
 };
 
-#define DateCalc_LANGUAGES 13
+#define DateCalc_LANGUAGES 14
 
-Z_int  DateCalc_Language = 1; /* Default = 1 (English) */
+Z_int DateCalc_Language = 1; /* Default = 1 (English) */
 
 const N_char DateCalc_Month_to_Text_[DateCalc_LANGUAGES+1][13][32] =
 {
@@ -463,8 +470,16 @@ const N_char DateCalc_Month_to_Text_[DateCalc_LANGUAGES+1][13][32] =
         "Jlius", "Augusztus", "Szeptember", "Oktber", "November", "December"
     },
     {
-        "???", "Stycze", "Luty", "Marzec", "Kwiecie", "Maj", "Czerwiec",
-        "Lipiec", "Sierpie", "Wrzesie", "Padziernik", "Listopad", "Grudzie"
+        "???", "stycznia", "lutego", "marca", "kwietnia", "maja", "czerwca",
+        "lipca", "sierpnia", "wrzesnia", "pazdziernika", "listopada", "grudnia"
+     /* "???", "Styczen", "Luty", "Marzec", "Kwiecien", "Maj", "Czerwiec", */ /* non-flected? */
+     /* "Lipiec", "Sierpien", "Wrzesien", "Pazdziernik", "Listopad", "Grudzien" */
+     /* "???", "Stycze", "Luty", "Marzec", "Kwiecie", "Maj", "Czerwiec", */ /* ISO-Latin-2 */
+     /* "Lipiec", "Sierpie", "Wrzesie", "Padziernik", "Listopad", "Grudzie" */
+    },
+    {
+        "???", "Ianuarie", "Februarie", "Martie", "Aprilie", "Mai", "Iunie",
+        "Iulie", "August", "Septembrie", "Octombrie", "Noiembrie", "Decembrie"
     }
 };
 
@@ -523,8 +538,16 @@ const N_char DateCalc_Day_of_Week_to_Text_[DateCalc_LANGUAGES+1][8][32] =
         "cstrtk", "pntek", "szombat", "vasrnap"
     },
     {
-        "???", "Poniedziaek", "Wtorek", "roda",
-        "Czwartek", "Pitek", "Sobota", "Niedziela"
+        "???", "poniedzialek", "wtorek", "srodek",
+        "czwartek", "piatek", "sobota", "niedziele"
+     /* "???", "Poniedzialek", "Wtorek", "Sroda", */ /* non-flected? */
+     /* "Czwartek", "Piatek", "Sobota", "Niedziela" */
+     /* "???", "Poniedziaek", "Wtorek", "roda", */ /* ISO-Latin-2 */
+     /* "Czwartek", "Pitek", "Sobota", "Niedziela" */
+    },
+    {
+        "???", "Luni", "Marti", "Miercuri",
+        "Joi", "Vineri", "Sambata", "Duminica"
     }
 };
 
@@ -573,7 +596,11 @@ const N_char DateCalc_Day_of_Week_Abbreviation_[DateCalc_LANGUAGES+1][8][4] =
         "", "", "", "", "", "", "", ""    /* 12 */
     },
     {
-        "???", "Pn", "Wt", "r", "Cz", "Pt", "So", "Ni"    /* 13 */
+        "???", "Pn", "Wt", "Sr", "Cz", "Pt", "So", "Ni"    /* 13 */
+     /* "???", "Pn", "Wt", "r", "Cz", "Pt", "So", "Ni" */ /* 13 */ /* ISO-Latin-2 */
+    },
+    {
+        "", "", "", "", "", "", "", ""    /* 14 */
     }
 };
 
@@ -600,14 +627,15 @@ const N_char DateCalc_Date_Long_Format_[DateCalc_LANGUAGES+1][64] =
     "%s, %d. %s %d",                    /* 10  Dansk       */
     "%s, %d. %sta %d",                  /* 11  suomi       */
     "%d. %s %d., %s",                   /* 12  Magyar      */
-    "%s, %d %s %d"                      /* 13  Polski      */
+    "%s, %d %s %d",                     /* 13  polski      */
+    "%s %d %s %d"                       /* 14  Romaneste   */
 };
 
 const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32] =
 {
     "???", "English", "Franais", "Deutsch", "Espaol",
     "Portugus", "Nederlands", "Italiano", "Norsk", "Svenska",
-    "Dansk", "suomi", "Magyar", "Polski"
+    "Dansk", "suomi", "Magyar", "polski", "Romaneste"
 };
 
 /*****************************************************************************/
@@ -1530,6 +1558,45 @@ boolean DateCalc_easter_sunday(Z_int *year, Z_int *month, Z_int *day)
 /*  Whitsunday / Pfingstsonntag / Dimanche de Pentecote    =  easter sunday + 49  */
 /*  Whitmonday / Pfingstmontag / Lundi de Pentecote        =  easter sunday + 50  */
 /*  Feast of Corpus Christi / Fronleichnam / Fete-Dieu     =  easter sunday + 60  */
+boolean DateCalc_easter_orthodox_sunday(Z_int *year, boolean julian, Z_int *month, Z_int *day)
+{
+    Z_int a, b, c, d, e, m, n;
+
+    if ((*year < 326) or (*year > 2299)) return(false);
+
+    m = 15;
+    n = 6;
+    
+    a = *year % 19;
+    b = *year % 4;
+    c = *year % 7;
+    d = (19 * a + m) % 30;
+    e = (2 * b + 4 * c + 6 * d + n) % 7;
+    *day = 22 + d + e;
+    *month = 3;
+
+    /* greek orthodox easter is calculated the julian calendar way, but then displaced to gregorian 
+       (actually, revised julian) calendar but not before 1923.
+       The difference between revised julian and gregorian calendar should not make any difference at
+       least until year 2800 */
+    if (julian == false && *year > 1922)
+    	*day += 13;
+
+    if (*day > 31)
+    {
+        *day -= 31;
+        (*month)++;
+    }
+    /* so it may go well into May */
+    if (*day > 30)
+    {
+        *day -= 30;
+        (*month)++;
+    }
+    
+    return(true);
+}
+
 
 Z_int DateCalc_Decode_Month(charptr buffer, Z_int length) /* 0 = error */
 {
@@ -2214,38 +2281,42 @@ void DateCalc_Dispose(charptr string)
 
 charptr DateCalc_Version(void)
 {
-    return( (charptr) "5.1" );
+    return( (charptr) "5.5" );
 }
 
 /*****************************************************************************/
-/*  VERSION:  5.1                                                            */
+/*  VERSION:  5.5                                                            */
 /*****************************************************************************/
 /*  VERSION HISTORY:                                                         */
 /*****************************************************************************/
 /*                                                                           */
-/*    Version 5.1   08.09.02  Added conditional changes for MacOS/MacPerl.   */
-/*    Version 5.0   10.10.01  New YMD/HMS functions, replaced <ctype.h>, ... */
-/*    Version 4.3   08.01.00  decode_date_??: (yy < 70 ? 20yy : 19yy)        */
-/*    Version 4.2   07.09.98  No changes.                                    */
-/*    Version 4.1   08.06.98  Fixed bug in "add_delta_ymd()".                */
-/*    Version 4.0   12.05.98  Major rework. Added multi-language support.    */
-/*    Version 3.2   15.06.97  Added "week_of_year()".                        */
-/*    Version 3.1   12.06.97  No significant changes.                        */
-/*    Version 3.0   16.02.97  Changed conventions for unsuccessful returns.  */
-/*    Version 2.3   22.11.96  Fixed unbalanced "malloc" and "free".          */
-/*    Version 2.2   26.05.96  No significant changes.                        */
-/*    Version 2.1   26.05.96  Fixed HH MM SS parameter checks.               */
-/*    Version 2.0   25.05.96  Added time calculations. Major rework.         */
-/*    Version 1.6   20.04.96  Not published.                                 */
-/*    Version 1.5   14.03.96  No significant changes.                        */
-/*    Version 1.4   11.02.96  No significant changes.                        */
-/*    Version 1.3   10.12.95  Added "days_in_month()".                       */
-/*    Version 1.2b  27.11.95  No significant changes.                        */
-/*    Version 1.2a  21.11.95  Fix for type name clashes.                     */
-/*    Version 1.1   18.11.95  Fix for type name clashes.                     */
-/*    Version 1.01  16.11.95  Improved compliance w/ programming standards.  */
-/*    Version 1.0   14.11.95  First version under UNIX (with Perl module).   */
-/*    Version 0.9   01.11.93  First version of C library under MS-DOS.       */
+/*    Version 5.5  23.01.07  Fixed compiler warning under gcc-4.             */
+/*    Version 5.4  03.10.04  Added compiler directives for C++.              */
+/*    Version 5.3  29.09.02  No changes.                                     */
+/*    Version 5.2  18.09.02  No changes.                                     */
+/*    Version 5.1  08.09.02  Added conditional changes for MacOS/MacPerl.    */
+/*    Version 5.0  10.10.01  New YMD/HMS functions, replaced <ctype.h>, ...  */
+/*    Version 4.3  08.01.00  decode_date_??: (yy < 70 ? 20yy : 19yy)         */
+/*    Version 4.2  07.09.98  No changes.                                     */
+/*    Version 4.1  08.06.98  Fixed bug in "add_delta_ymd()".                 */
+/*    Version 4.0  12.05.98  Major rework. Added multi-language support.     */
+/*    Version 3.2  15.06.97  Added "week_of_year()".                         */
+/*    Version 3.1  12.06.97  No significant changes.                         */
+/*    Version 3.0  16.02.97  Changed conventions for unsuccessful returns.   */
+/*    Version 2.3  22.11.96  Fixed unbalanced "malloc" and "free".           */
+/*    Version 2.2  26.05.96  No significant changes.                         */
+/*    Version 2.1  26.05.96  Fixed HH MM SS parameter checks.                */
+/*    Version 2.0  25.05.96  Added time calculations. Major rework.          */
+/*    Version 1.6  20.04.96  Not published.                                  */
+/*    Version 1.5  14.03.96  No significant changes.                         */
+/*    Version 1.4  11.02.96  No significant changes.                         */
+/*    Version 1.3  10.12.95  Added "days_in_month()".                        */
+/*    Version 1.2b 27.11.95  No significant changes.                         */
+/*    Version 1.2a 21.11.95  Fix for type name clashes.                      */
+/*    Version 1.1  18.11.95  Fix for type name clashes.                      */
+/*    Version 1.01 16.11.95  Improved compliance w/ programming standards.   */
+/*    Version 1.0  14.11.95  First version under UNIX (with Perl module).    */
+/*    Version 0.9  01.11.93  First version of C library under MS-DOS.        */
 /*                                                                           */
 /*****************************************************************************/
 /*  AUTHOR:                                                                  */
@@ -2259,7 +2330,7 @@ charptr DateCalc_Version(void)
 /*  COPYRIGHT:                                                               */
 /*****************************************************************************/
 /*                                                                           */
-/*    Copyright (c) 1993 - 2002 by Steffen Beyer.                            */
+/*    Copyright (c) 1993 - 2004 by Steffen Beyer.                            */
 /*    All rights reserved.                                                   */
 /*                                                                           */
 /*****************************************************************************/
