@@ -1,5 +1,9 @@
 #ifndef MODULE_DATE_CALC
 #define MODULE_DATE_CALC
+#ifdef __cplusplus
+extern "C"
+{
+#endif
 /*****************************************************************************/
 /*  MODULE NAME:  DateCalc.h                            MODULE TYPE:  (lib)  */
 /*****************************************************************************/
@@ -304,6 +308,13 @@ DateCalc_easter_sunday                 (Z_int  *year,       /*  I/O  */
                                         Z_int  *month,      /*   O   */
                                         Z_int  *day);       /*   O   */
 
+boolean
+DateCalc_easter_orthodox_sunday        (Z_int  *year,       /*  I/O  */
+										boolean julian,     /*   I   */
+                                        Z_int  *month,      /*   O   */
+                                        Z_int  *day);       /*   O   */
+                                        
+
 Z_int
 DateCalc_Decode_Month                  (charptr buffer,
                                         Z_int   length);
@@ -407,9 +418,9 @@ extern const Z_int DateCalc_Days_in_Month_[2][13];
 };
 */
 
-#define DateCalc_LANGUAGES 13
+#define DateCalc_LANGUAGES 14
 
-extern Z_int  DateCalc_Language; /* Default = 1 (English) */
+extern Z_int DateCalc_Language; /* Default = 1 (English) */
 
 extern const N_char DateCalc_Month_to_Text_[DateCalc_LANGUAGES+1][13][32];
 /*
@@ -468,8 +479,12 @@ extern const N_char DateCalc_Month_to_Text_[DateCalc_LANGUAGES+1][13][32];
         "Jlius", "Augusztus", "Szeptember", "Oktber", "November", "December"
     },
     {
-        "???", "Stycze", "Luty", "Marzec", "Kwiecie", "Maj", "Czerwiec",
-        "Lipiec", "Sierpie", "Wrzesie", "Padziernik", "Listopad", "Grudzie"
+        "???", "stycznia", "lutego", "marca", "kwietnia", "maja", "czerwca",
+        "lipca", "sierpnia", "wrzesnia", "pazdziernika", "listopada", "grudnia"
+    },
+    {
+        "???", "Ianuarie", "Februarie", "Martie", "Aprilie", "Mai", "Iunie",
+        "Iulie", "August", "Septembrie", "Octombrie", "Noiembrie", "Decembrie"
     }
 };
 */
@@ -530,8 +545,12 @@ extern const N_char DateCalc_Day_of_Week_to_Text_[DateCalc_LANGUAGES+1][8][32];
         "cstrtk", "pntek", "szombat", "vasrnap"
     },
     {
-        "???", "Poniedziaek", "Wtorek", "roda",
-        "Czwartek", "Pitek", "Sobota", "Niedziela"
+        "???", "poniedzialek", "wtorek", "srodek",
+        "czwartek", "piatek", "sobota", "niedziele"
+    },
+    {
+        "???", "Luni", "Marti", "Miercuri",
+        "Joi", "Vineri", "Sambata", "Duminica"
     }
 };
 */
@@ -582,7 +601,10 @@ extern const N_char DateCalc_Day_of_Week_Abbreviation_[DateCalc_LANGUAGES+1][8][
         "", "", "", "", "", "", "", ""
     },
     {
-        "???", "Pn", "Wt", "r", "Cz", "Pt", "So", "Ni"
+        "???", "Pn", "Wt", "Sr", "Cz", "Pt", "So", "Ni"
+    },
+    {
+        "", "", "", "", "", "", "", ""
     }
 };
 */
@@ -613,7 +635,8 @@ extern const N_char DateCalc_Date_Long_Format_[DateCalc_LANGUAGES+1][64];
     "%s, %d. %s %d",
     "%s, %d. %sta %d",
     "%d. %s %d., %s",
-    "%s, %d %s %d"
+    "%s, %d %s %d",
+    "%s %d %s %d"
 };
 */
 
@@ -622,7 +645,7 @@ extern const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32];
 {
     "???", "English", "Franais", "Deutsch", "Espaol",
     "Portugus", "Nederlands", "Italiano", "Norsk", "Svenska",
-    "Dansk", "suomi", "Magyar", "Polski"
+    "Dansk", "suomi", "Magyar", "polski", "Romaneste"
 };
 */
 
@@ -631,34 +654,38 @@ extern const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32];
 /*****************************************************************************/
 
 /*****************************************************************************/
-/*  VERSION:  5.1                                                            */
+/*  VERSION:  5.5                                                            */
 /*****************************************************************************/
 /*  VERSION HISTORY:                                                         */
 /*****************************************************************************/
 /*                                                                           */
-/*    Version 5.1   08.09.02  Added conditional changes for MacOS/MacPerl.   */
-/*    Version 5.0   10.10.01  New YMD/HMS functions, replaced <ctype.h>, ... */
-/*    Version 4.3   08.01.00  decode_date_??: (yy < 70 ? 20yy : 19yy)        */
-/*    Version 4.2   07.09.98  No changes.                                    */
-/*    Version 4.1   08.06.98  Fixed bug in "add_delta_ymd()".                */
-/*    Version 4.0   12.05.98  Major rework. Added multi-language support.    */
-/*    Version 3.2   15.06.97  Added "week_of_year()".                        */
-/*    Version 3.1   12.06.97  No significant changes.                        */
-/*    Version 3.0   16.02.97  Changed conventions for unsuccessful returns.  */
-/*    Version 2.3   22.11.96  Fixed unbalanced "malloc" and "free".          */
-/*    Version 2.2   26.05.96  No significant changes.                        */
-/*    Version 2.1   26.05.96  Fixed HH MM SS parameter checks.               */
-/*    Version 2.0   25.05.96  Added time calculations. Major rework.         */
-/*    Version 1.6   20.04.96  Not published.                                 */
-/*    Version 1.5   14.03.96  No significant changes.                        */
-/*    Version 1.4   11.02.96  No significant changes.                        */
-/*    Version 1.3   10.12.95  Added "days_in_month()".                       */
-/*    Version 1.2b  27.11.95  No significant changes.                        */
-/*    Version 1.2a  21.11.95  Fix for type name clashes.                     */
-/*    Version 1.1   18.11.95  Fix for type name clashes.                     */
-/*    Version 1.01  16.11.95  Improved compliance w/ programming standards.  */
-/*    Version 1.0   14.11.95  First version under UNIX (with Perl module).   */
-/*    Version 0.9   01.11.93  First version of C library under MS-DOS.       */
+/*    Version 5.5  23.01.07  Fixed compiler warning under gcc-4.             */
+/*    Version 5.4  03.10.04  Added compiler directives for C++.              */
+/*    Version 5.3  29.09.02  No changes.                                     */
+/*    Version 5.2  18.09.02  No changes.                                     */
+/*    Version 5.1  08.09.02  Added conditional changes for MacOS/MacPerl.    */
+/*    Version 5.0  10.10.01  New YMD/HMS functions, replaced <ctype.h>, ...  */
+/*    Version 4.3  08.01.00  decode_date_??: (yy < 70 ? 20yy : 19yy)         */
+/*    Version 4.2  07.09.98  No changes.                                     */
+/*    Version 4.1  08.06.98  Fixed bug in "add_delta_ymd()".                 */
+/*    Version 4.0  12.05.98  Major rework. Added multi-language support.     */
+/*    Version 3.2  15.06.97  Added "week_of_year()".                         */
+/*    Version 3.1  12.06.97  No significant changes.                         */
+/*    Version 3.0  16.02.97  Changed conventions for unsuccessful returns.   */
+/*    Version 2.3  22.11.96  Fixed unbalanced "malloc" and "free".           */
+/*    Version 2.2  26.05.96  No significant changes.                         */
+/*    Version 2.1  26.05.96  Fixed HH MM SS parameter checks.                */
+/*    Version 2.0  25.05.96  Added time calculations. Major rework.          */
+/*    Version 1.6  20.04.96  Not published.                                  */
+/*    Version 1.5  14.03.96  No significant changes.                         */
+/*    Version 1.4  11.02.96  No significant changes.                         */
+/*    Version 1.3  10.12.95  Added "days_in_month()".                        */
+/*    Version 1.2b 27.11.95  No significant changes.                         */
+/*    Version 1.2a 21.11.95  Fix for type name clashes.                      */
+/*    Version 1.1  18.11.95  Fix for type name clashes.                      */
+/*    Version 1.01 16.11.95  Improved compliance w/ programming standards.   */
+/*    Version 1.0  14.11.95  First version under UNIX (with Perl module).    */
+/*    Version 0.9  01.11.93  First version of C library under MS-DOS.        */
 /*                                                                           */
 /*****************************************************************************/
 /*  AUTHOR:                                                                  */
@@ -672,7 +699,7 @@ extern const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32];
 /*  COPYRIGHT:                                                               */
 /*****************************************************************************/
 /*                                                                           */
-/*    Copyright (c) 1993 - 2002 by Steffen Beyer.                            */
+/*    Copyright (c) 1993 - 2004 by Steffen Beyer.                            */
 /*    All rights reserved.                                                   */
 /*                                                                           */
 /*****************************************************************************/
@@ -696,4 +723,7 @@ extern const N_char DateCalc_Language_to_Text_[DateCalc_LANGUAGES+1][32];
 /*    or download a copy from ftp://ftp.gnu.org/pub/gnu/COPYING.LIB-2.0      */
 /*                                                                           */
 /*****************************************************************************/
+#ifdef __cplusplus
+}
+#endif
 #endif
